@@ -1,18 +1,20 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- *  Unless required by applicable law or agreed to in writing, software
- *  distributed under the License is distributed on an "AS IS" BASIS,
- *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- *  See the License for the specific language governing permissions and
- *  limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.bcel.classfile;
 
@@ -25,7 +27,7 @@ import java.util.Iterator;
 import org.apache.bcel.Const;
 
 /**
- * This class represents the constant pool, i.e., a table of constants, of a parsed classfile. It may contain null references, due to the JVM specification that
+ * This class represents the constant pool, that is, a table of constants, of a parsed classfile. It may contain null references, due to the JVM specification that
  * skips an entry after an 8-byte constant (double, long) entry. Those interested in generating constant pools programmatically should see
  * <a href="../generic/ConstantPoolGen.html"> ConstantPoolGen</a>.
  *
@@ -65,17 +67,19 @@ public class ConstantPool implements Cloneable, Node, Iterable<Constant> {
     private Constant[] constantPool;
 
     /**
-     * @param constantPool Array of constants
+     * Constructs a ConstantPool.
+     *
+     * @param constantPool Array of constants.
      */
-    public ConstantPool(final Constant[] constantPool) {
+    public ConstantPool(final Constant... constantPool) {
         setConstantPool(constantPool);
     }
 
     /**
      * Reads constants from given input stream.
      *
-     * @param input Input stream
-     * @throws IOException if problem in readUnsignedShort or readConstant
+     * @param input Input stream.
+     * @throws IOException if problem in readUnsignedShort or readConstant.
      */
     public ConstantPool(final DataInput input) throws IOException {
         byte tag;
@@ -104,7 +108,7 @@ public class ConstantPool implements Cloneable, Node, Iterable<Constant> {
      * Called by objects that are traversing the nodes of the tree implicitly defined by the contents of a Java class. I.e., the hierarchy of methods, fields,
      * attributes, etc. spawns a tree of objects.
      *
-     * @param v Visitor object
+     * @param v Visitor object.
      */
     @Override
     public void accept(final Visitor v) {
@@ -114,13 +118,13 @@ public class ConstantPool implements Cloneable, Node, Iterable<Constant> {
     /**
      * Resolves constant to a string representation.
      *
-     * @param c Constant to be printed
-     * @return String representation
-     * @throws IllegalArgumentException if c is unknown constant type
+     * @param c Constant to be printed.
+     * @return String representation.
+     * @throws IllegalArgumentException if c is unknown constant type.
      */
     public String constantToString(Constant c) throws IllegalArgumentException {
-        String str;
-        int i;
+        final String str;
+        final int i;
         final byte tag = c.getTag();
         switch (tag) {
         case Const.CONSTANT_Class:
@@ -196,16 +200,18 @@ public class ConstantPool implements Cloneable, Node, Iterable<Constant> {
     /**
      * Retrieves constant at 'index' from constant pool and resolve it to a string representation.
      *
-     * @param index of constant in constant pool
-     * @param tag   expected type
-     * @return String representation
+     * @param index of constant in constant pool.
+     * @param tag   expected type.
+     * @return String representation.
      */
     public String constantToString(final int index, final byte tag) {
         return constantToString(getConstant(index, tag));
     }
 
     /**
-     * @return deep copy of this constant pool
+     * Creates a deep copy of this constant pool.
+     *
+     * @return deep copy of this constant pool.
      */
     public ConstantPool copy() {
         ConstantPool c = null;
@@ -224,9 +230,9 @@ public class ConstantPool implements Cloneable, Node, Iterable<Constant> {
     }
 
     /**
-     * Dump constant pool to file stream in binary format.
+     * Dumps constant pool to file stream in binary format.
      *
-     * @param file Output file stream
+     * @param file Output file stream.
      * @throws IOException if problem in writeShort or dump
      */
     public void dump(final DataOutputStream file) throws IOException {
@@ -247,10 +253,11 @@ public class ConstantPool implements Cloneable, Node, Iterable<Constant> {
     /**
      * Gets constant from constant pool.
      *
-     * @param index Index in constant pool
-     * @return Constant value
+     * @param <T> the type of the constant.
+     * @param index Index in constant pool.
+     * @return Constant value.
      * @see Constant
-     * @throws ClassFormatException if index is invalid
+     * @throws ClassFormatException if index is invalid.
      */
     @SuppressWarnings("unchecked")
     public <T extends Constant> T getConstant(final int index) throws ClassFormatException {
@@ -260,11 +267,12 @@ public class ConstantPool implements Cloneable, Node, Iterable<Constant> {
     /**
      * Gets constant from constant pool and check whether it has the expected type.
      *
-     * @param index Index in constant pool
-     * @param tag   Tag of expected constant, i.e., its type
-     * @return Constant value
+     * @param <T> the type of the constant.
+     * @param index Index in constant pool.
+     * @param tag   Tag of expected constant, that is, its type.
+     * @return Constant value.
      * @see Constant
-     * @throws ClassFormatException if constant type does not match tag
+     * @throws ClassFormatException if constant type does not match tag.
      */
     @SuppressWarnings("unchecked")
     public <T extends Constant> T getConstant(final int index, final byte tag) throws ClassFormatException {
@@ -274,11 +282,13 @@ public class ConstantPool implements Cloneable, Node, Iterable<Constant> {
     /**
      * Gets constant from constant pool and check whether it has the expected type.
      *
-     * @param index Index in constant pool
-     * @param tag   Tag of expected constant, i.e., its type
-     * @return Constant value
+     * @param <T> the type of the constant.
+     * @param index Index in constant pool.
+     * @param tag   Tag of expected constant, that is, its type.
+     * @param castTo the class to cast to.
+     * @return Constant value.
      * @see Constant
-     * @throws ClassFormatException if constant type does not match tag
+     * @throws ClassFormatException if constant type does not match tag.
      * @since 6.6.0
      */
     public <T extends Constant> T getConstant(final int index, final byte tag, final Class<T> castTo) throws ClassFormatException {
@@ -292,12 +302,12 @@ public class ConstantPool implements Cloneable, Node, Iterable<Constant> {
     /**
      * Gets constant from constant pool.
      *
-     * @param <T> A {@link Constant} subclass
-     * @param index Index in constant pool
+     * @param <T> A {@link Constant} subclass.
+     * @param index Index in constant pool.
      * @param castTo The {@link Constant} subclass to cast to.
-     * @return Constant value
+     * @return Constant value.
+     * @throws ClassFormatException if index is invalid.
      * @see Constant
-     * @throws ClassFormatException if index is invalid
      * @since 6.6.0
      */
     public <T extends Constant> T getConstant(final int index, final Class<T> castTo) throws ClassFormatException {
@@ -326,16 +336,18 @@ public class ConstantPool implements Cloneable, Node, Iterable<Constant> {
     /**
      * Gets constant from constant pool and check whether it has the expected type.
      *
-     * @param index Index in constant pool
-     * @return ConstantInteger value
+     * @param index Index in constant pool.
+     * @return ConstantInteger value.
+     * @throws ClassFormatException if constant type does not match tag.
      * @see ConstantInteger
-     * @throws ClassFormatException if constant type does not match tag
      */
     public ConstantInteger getConstantInteger(final int index) {
         return getConstant(index, Const.CONSTANT_Integer, ConstantInteger.class);
     }
 
     /**
+     * Gets the array of constants.
+     *
      * @return Array of constants.
      * @see Constant
      */
@@ -347,15 +359,15 @@ public class ConstantPool implements Cloneable, Node, Iterable<Constant> {
      * Gets string from constant pool and bypass the indirection of 'ConstantClass' and 'ConstantString' objects. I.e. these classes have an index field that
      * points to another entry of the constant pool of type 'ConstantUtf8' which contains the real data.
      *
-     * @param index Index in constant pool
-     * @param tag   Tag of expected constant, either ConstantClass or ConstantString
-     * @return Contents of string reference
+     * @param index Index in constant pool.
+     * @param tag   Tag of expected constant, either ConstantClass or ConstantString.
+     * @return Contents of string reference.
+     * @throws IllegalArgumentException if tag is invalid.
      * @see ConstantClass
      * @see ConstantString
-     * @throws IllegalArgumentException if tag is invalid
      */
     public String getConstantString(final int index, final byte tag) throws IllegalArgumentException {
-        int i;
+        final int i;
         /*
          * This switch() is not that elegant, since the four classes have the same contents, they just differ in the name of the index field variable. But we
          * want to stick to the JVM naming conventions closely though we could have solved these more elegantly by using the same variable name or by
@@ -386,16 +398,18 @@ public class ConstantPool implements Cloneable, Node, Iterable<Constant> {
     /**
      * Gets constant from constant pool and check whether it has the expected type.
      *
-     * @param index Index in constant pool
-     * @return ConstantUtf8 value
+     * @param index Index in constant pool.
+     * @return ConstantUtf8 value.
+     * @throws ClassFormatException if constant type does not match tag.
      * @see ConstantUtf8
-     * @throws ClassFormatException if constant type does not match tag
      */
     public ConstantUtf8 getConstantUtf8(final int index) throws ClassFormatException {
         return getConstant(index, Const.CONSTANT_Utf8, ConstantUtf8.class);
     }
 
     /**
+     * Gets the length of constant pool.
+     *
      * @return Length of constant pool.
      */
     public int getLength() {
@@ -408,14 +422,19 @@ public class ConstantPool implements Cloneable, Node, Iterable<Constant> {
     }
 
     /**
-     * @param constant Constant to set
+     * Sets a constant at the specified index.
+     *
+     * @param index the index in the constant pool.
+     * @param constant Constant to set.
      */
     public void setConstant(final int index, final Constant constant) {
         constantPool[index] = constant;
     }
 
     /**
-     * @param constantPool
+     * Sets the constant pool.
+     *
+     * @param constantPool the constant pool array.
      */
     public void setConstantPool(final Constant[] constantPool) {
         this.constantPool = constantPool != null ? constantPool : Constant.EMPTY_ARRAY;
