@@ -16,6 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
+
 package org.apache.bcel.classfile;
 
 import java.io.DataInput;
@@ -24,9 +25,10 @@ import java.io.IOException;
 import java.util.Arrays;
 
 import org.apache.bcel.Const;
+import org.apache.commons.lang3.SystemProperties;
 
 /**
- * This class represents a reference to an unknown (i.e., application-specific) attribute of a class. It is instantiated
+ * This class represents a reference to an unknown (that is, application-specific) attribute of a class. It is instantiated
  * from the {@link Attribute#readAttribute(java.io.DataInput, ConstantPool)} method. Applications that need to read in
  * application-specific attributes should create an {@link UnknownAttributeReader} implementation and attach it via
  * {@link Attribute#addAttributeReader(String, UnknownAttributeReader)}.
@@ -36,6 +38,13 @@ import org.apache.bcel.Const;
  */
 public final class Unknown extends Attribute {
 
+    /**
+     * Arbitrary to limit the maximum length of unknown attributes to avoid OOM errors.
+     */
+    static final int MAX_LEN = 1_000_000;
+
+    private static final String MAX_LEN_PROP = "BCEL.Attribute.Unknown.max_attribute_length";
+
     private byte[] bytes;
 
     private final String name;
@@ -43,10 +52,10 @@ public final class Unknown extends Attribute {
     /**
      * Constructs a new instance for a non-standard attribute.
      *
-     * @param nameIndex Index in constant pool
-     * @param length Content length in bytes
-     * @param bytes Attribute contents
-     * @param constantPool Array of constants
+     * @param nameIndex Index in constant pool.
+     * @param length Content length in bytes.
+     * @param bytes Attribute contents.
+     * @param constantPool Array of constants.
      */
     public Unknown(final int nameIndex, final int length, final byte[] bytes, final ConstantPool constantPool) {
         super(Const.ATTR_UNKNOWN, nameIndex, length, constantPool);
@@ -55,17 +64,26 @@ public final class Unknown extends Attribute {
     }
 
     /**
-     * Constructs a new instance from an input stream.
+     * Constructs a new instance from a DataInput.
+     * <p>
+     * The size of an <a href="https://docs.oracle.com/javase/specs/jvms/se25/html/jvms-4.html#jvms-4.7">Attribute</a> unknown to the JVM specification is
+     * limited to 1 MB and is overridden with the system property {@code BCEL.Attribute.Unknown.max_attribute_length}.
+     * </p>
      *
-     * @param nameIndex Index in constant pool
-     * @param length Content length in bytes
-     * @param input Input stream
-     * @param constantPool Array of constants
+     * @param nameIndex    Index in constant pool.
+     * @param length       Content length in bytes.
+     * @param input        Input stream.
+     * @param constantPool Array of constants.
      * @throws IOException if an I/O error occurs.
+     * @see <a href="https://docs.oracle.com/javase/specs/jvms/se25/html/jvms-4.html#jvms-4.7">Attribute</a>
      */
     Unknown(final int nameIndex, final int length, final DataInput input, final ConstantPool constantPool) throws IOException {
         this(nameIndex, length, (byte[]) null, constantPool);
         if (length > 0) {
+            if (length > SystemProperties.getInt(MAX_LEN_PROP, () -> MAX_LEN)) {
+                throw new IOException(
+                        String.format("Unknown attribute length %,d > %,d; use the %s system property to increase the limit.", length, MAX_LEN, MAX_LEN_PROP));
+            }
             bytes = new byte[length];
             input.readFully(bytes);
         }
@@ -84,7 +102,7 @@ public final class Unknown extends Attribute {
      * Called by objects that are traversing the nodes of the tree implicitly defined by the contents of a Java class.
      * I.e., the hierarchy of methods, fields, attributes, etc. spawns a tree of objects.
      *
-     * @param v Visitor object
+     * @param v Visitor object.
      */
     @Override
     public void accept(final Visitor v) {
@@ -92,7 +110,7 @@ public final class Unknown extends Attribute {
     }
 
     /**
-     * @return deep copy of this attribute
+     * @return deep copy of this attribute.
      */
     @Override
     public Attribute copy(final ConstantPool constantPool) {
@@ -107,7 +125,7 @@ public final class Unknown extends Attribute {
     /**
      * Dumps unknown bytes to file stream.
      *
-     * @param file Output file stream
+     * @param file Output file stream.
      * @throws IOException if an I/O error occurs.
      */
     @Override
@@ -134,7 +152,7 @@ public final class Unknown extends Attribute {
     }
 
     /**
-     * @param bytes the bytes to set
+     * @param bytes the bytes to set.
      */
     public void setBytes(final byte[] bytes) {
         this.bytes = bytes;
